-- Tile-based platforming engine by Samuel Wallis (Squeegy)
-- With help from various Internet tutorials
-- All rights reserved

require "utilities"
require "config"
require "AnAL"
require "resources"
require "camera"
require "Player/player"

function love.load()
	loadConfig()
	loadResources()
	width = love.graphics.getWidth()
	height = love.graphics.getHeight()
	love.graphics.setBackgroundColor(40, 40, 40)

	-- Load up the map
	loader = require("AdvTiledLoader.Loader")
	loader.path = "maps/"
	map = loader.load("map01.tmx")
	map:setDrawRange(0, 0, map.width * map.tileWidth, map.height * map.tileHeight)

	--Create the player
	p = Player:new()
	p.x = 300
	p.y = 300
	p.anim = p.animStand
	
	-- Restrict the camera
	camera:setBounds(0, 0, map.width * map.tileWidth - width, map.height * map.tileHeight - height)

	--Set global variables
	gravity = 600

end    

function love.update(dt)
	updateKeys()
	
	-- update the player's position and check for map collisions
	p:update(gravity, dt)
	camera:setPosition(math.floor(p.x - width / 2), math.floor(p.y - height / 2))
end

function love.keypressed(k, uni)
	for a, key in pairs(config.keys) do
		if k == key then
			p:action(a)
		end
	end
end

function love.draw()
	camera:set()
	
	-- round our x, y values
	local x, y = math.floor(p.x), math.floor(p.y)

	-- draw the map
	map:draw()

	-- draw the player
	p:draw()
	
	camera:unset()
	
	-- debug information
	local tileX = math.floor(p.x / map.tileWidth)
	local tileY = math.floor(p.y / map.tileHeight)
	
	love.graphics.setColor(255, 255, 255)
	love.graphics.print("Player coordinates: ("..x..","..y..")", 5, 5)
	love.graphics.print("Current state: "..p.state, 5, 20)
	love.graphics.print("On ground: "..tostring(p.onGround), 5, 35)
	love.graphics.print("Current tile: ("..tileX..", "..tileY..")", 5, 50)
	love.graphics.print("Left: "..tostring(keystate.left), 5, 65)
	love.graphics.print("Right: "..tostring(keystate.right), 5, 80)
	love.graphics.print("Up: "..tostring(keystate.up), 5, 95)
	love.graphics.print("Down: "..tostring(keystate.down), 5, 110)
	love.graphics.print("Xspeed: "..p.xspeed, 5, 125)
	love.graphics.print("Yspeed: "..p.yspeed, 5, 140)
end

function love.keyreleased(key)
	if key == "escape" then
		love.event.push("quit")   -- actually causes the app to quit
	end
end

--- Updates keystates of ingame keys.
function updateKeys()
	-- Check keyboard keys
	for action, key in pairs(config.keys) do
		if love.keyboard.isDown(key) then
			keystate[action] = true
		else
			keystate[action] = false
		end
	end
end